tietools.get_nontrivial_tie_chains_masked_by_components
=======================================================

.. autofunction:: abjad.tools.tietools.get_nontrivial_tie_chains_masked_by_components.get_nontrivial_tie_chains_masked_by_components
   :noindex:
